CA01-Cl09
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Section |
clickAndWait | link=Añadir section |
type | id_name_es | CA01-Cl09 Section
type | id_slug | ca01-cl09-section
select | id_status | label=Borrador
clickAndWait | _continue |
verifyText | link=CA01-Cl09 Section | CA01-Cl09 Section
click | //div[@id='content']/ul/div/li/a[2] |
verifyText | link=estilo personalizado | estilo personalizado
verifyTextPresent | estilo personalizado |
verifyText | link=documentos | documentos
verifyTextPresent | documentos |
verifyText | link=menú principal | menú principal
verifyTextPresent | menú principal |
verifyTextPresent | event |
verifyText | link=event | event
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |